---
name: Request for Help
about: Don't post help requests here, go to [discussions](http://github.com/deepmodeling/dpgen/discussions)
  instead. Or [choose a different type]( https://github.com/deepmodeling/dpgen/issues/new/choose).
title: ''
labels: ''
assignees: ''

---

Before asking questions, you can

search the previous issues or discussions
check [Manual](https://github.com/deepmodeling/dpgen).

Please **do not** post requests for help (e.g. with installing or using dpgen) here. 
Instead go to [discussions](https://github.com/deepmodeling/dpgen/discussions).

This issue tracker is for tracking dpgen development related issues only.

Thanks for your cooperation.
